==> kolourpaint-17.08.0.tar.xz: kolourpaint-17.08.0/commands/imagelib/effects/kpEffectBalanceCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectBalanceCommand_H
#define kpEffectBalanceCommand_H


#include "kpEffectCommandBase.h"
#include "imagelib/kpImage.h"


class kpEffectBalanceCommand : public kpEffectCommandBase
{
public:
    // (<brightness>, <contrast> & <gamma> are from -50 to 50)
    kpEffectBalanceCommand (int channels,
                            int brightness, int contrast, int gamma,
                            bool actOnSelection,
                            kpCommandEnvironment *environ);
    virtual ~kpEffectBalanceCommand ();

protected:
    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;

protected:
    int m_channels;
    int m_brightness, m_contrast, m_gamma;
};


#endif  // kpEffectBalanceCommand_H

==> kolourpaint-21.12.3.tar.xz: kolourpaint-21.12.3/commands/imagelib/effects/kpEffectBalanceCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpEffectBalanceCommand_H
#define kpEffectBalanceCommand_H


#include "kpEffectCommandBase.h"
#include "imagelib/kpImage.h"


class kpEffectBalanceCommand : public kpEffectCommandBase
{
public:
    // (<brightness>, <contrast> & <gamma> are from -50 to 50)
    kpEffectBalanceCommand (int channels,
                            int brightness, int contrast, int gamma,
                            bool actOnSelection,
                            kpCommandEnvironment *environ);
    ~kpEffectBalanceCommand () override;

protected:
    kpImage applyEffect (const kpImage &image) override;

protected:
    int m_channels;
    int m_brightness, m_contrast, m_gamma;
};


#endif  // kpEffectBalanceCommand_H
